==> parse_tree-0.0.1.tgz: parse_tree-0.0.1/parse_tree.c <==
/*
   +----------------------------------------------------------------------+
   | This source file is subject to version 3.0 of the PHP license,       |
   | that is bundled with this package in the file LICENSE, and is        |
   | available through the world-wide-web at the following url:           |
   | http://www.php.net/license/3_0.txt.                                  |
   | If you did not receive a copy of the PHP license and are unable to   |
   | obtain it through the world-wide-web, please send a note to          |
   | license@php.net so we can mail you a copy immediately.               |
   +----------------------------------------------------------------------+
   | Authors: William Candillon <wcandillon@php.net>                      |
   +----------------------------------------------------------------------+
*/

/* $ Id: $ */ 

#include "php_parse_tree.h"

#if HAVE_PARSE_TREE

/* {{{ parse_tree_functions[] */
function_entry parse_tree_functions[] = {
	PHP_FE(generate_parse_tree , NULL)
	{ NULL, NULL, NULL }
};
/* }}} */


/* {{{ parse_tree_module_entry
 */
zend_module_entry parse_tree_module_entry = {
	STANDARD_MODULE_HEADER,
	"parse_tree",
	parse_tree_functions,
	PHP_MINIT(parse_tree),     /* Replace with NULL if there is nothing to do at php startup   */ 
	PHP_MSHUTDOWN(parse_tree), /* Replace with NULL if there is nothing to do at php shutdown  */
	PHP_RINIT(parse_tree),     /* Replace with NULL if there is nothing to do at request start */
	PHP_RSHUTDOWN(parse_tree), /* Replace with NULL if there is nothing to do at request end   */
	PHP_MINFO(parse_tree),
	"0.0.1", 
	STANDARD_MODULE_PROPERTIES
};
/* }}} */

#ifdef COMPILE_DL_PARSE_TREE
ZEND_GET_MODULE(parse_tree)
#endif


/* {{{ PHP_MINIT_FUNCTION */
PHP_MINIT_FUNCTION(parse_tree)
{

	/* add your stuff here */

	return SUCCESS;
}
/* }}} */


/* {{{ PHP_MSHUTDOWN_FUNCTION */
PHP_MSHUTDOWN_FUNCTION(parse_tree)
{

	/* add your stuff here */

	return SUCCESS;
}
/* }}} */


/* {{{ PHP_RINIT_FUNCTION */
PHP_RINIT_FUNCTION(parse_tree)
{
	/* add your stuff here */

	return SUCCESS;
}
/* }}} */


/* {{{ PHP_RSHUTDOWN_FUNCTION */
PHP_RSHUTDOWN_FUNCTION(parse_tree)
{
	/* add your stuff here */

	return SUCCESS;
}
/* }}} */


/* {{{ PHP_MINFO_FUNCTION */
PHP_MINFO_FUNCTION(parse_tree)
{
	php_info_print_box_start(0);
	php_printf("<p>Generate an XML parse tree from a php source code</p>\n");
	php_printf("<p>Version 0.0.1alpha (2006-07-01)</p>\n");
	php_printf("<p><b>Authors:</b></p>\n");
	php_printf("<p>William Candillon &lt;wcandillon@php.net&gt; (lead)</p>\n");
	php_info_print_box_end();
	/* add your stuff here */

}
/* }}} */


/* {{{ proto void generate_parse_tree(string filename)
  Generate an XML parse tree from a php source code */
PHP_FUNCTION(generate_parse_tree)
{
	const char * filename = NULL;
	int filename_len = 0;

	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "s/", &filename, &filename_len) == FAILURE) { 
		return;
	}
	do {
#line 38 "parse_tree.xml"
						extern char* file_name;
						extern FILE* yyin;
						extern char* _xml_output;
						char * filename;
						int filename_len;
						extern int _error;
						
						if(zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "s", &filename, &filename_len) == FAILURE){
							return;
						}
						//file_name = 
						file_name = filename;
						yyin = fopen(filename, "r");
						yyparse();
						fclose(yyin);
						if(_error){
							return;	
						}
						ZVAL_STRING(return_value, _xml_output,1);
						return;
	} while(0);
}
/* }}} generate_parse_tree */

#endif /* HAVE_PARSE_TREE */


/*
 * Local variables:
 * tab-width: 4
 * c-basic-offset: 4
 * End:
 * vim600: noet sw=4 ts=4 fdm=marker
 * vim<600: noet sw=4 ts=4
 */

==> parse_tree-0.1.1.tgz: parse_tree-0.1.1/parse_tree.c <==
/*
   +----------------------------------------------------------------------+
   | This source file is subject to version 3.0 of the PHP license,       |
   | that is bundled with this package in the file LICENSE, and is        |
   | available through the world-wide-web at the following url:           |
   | http://www.php.net/license/3_0.txt.                                  |
   | If you did not receive a copy of the PHP license and are unable to   |
   | obtain it through the world-wide-web, please send a note to          |
   | license@php.net so we can mail you a copy immediately.               |
   +----------------------------------------------------------------------+
   | Authors: William Candillon <wcandillon@php.net>                      |
   +----------------------------------------------------------------------+
*/

/* $ Id: $ */ 

#include "php_parse_tree.h"

#if HAVE_PARSE_TREE

/* {{{ parse_tree_functions[] */
function_entry parse_tree_functions[] = {
	PHP_FE(parse_tree_from_file, NULL)
	{ NULL, NULL, NULL }
};
/* }}} */

/* {{{ parse_tree_module_entry
 */
zend_module_entry parse_tree_module_entry = {
	STANDARD_MODULE_HEADER,
	"parse_tree",
	parse_tree_functions,
	PHP_MINIT(parse_tree), 
	PHP_MSHUTDOWN(parse_tree),
	NULL,
	NULL,
	PHP_MINFO(parse_tree),
	"0.1.0", 
	STANDARD_MODULE_PROPERTIES
};
/* }}} */

#ifdef COMPILE_DL_PARSE_TREE
ZEND_GET_MODULE(parse_tree)
#endif

/* {{{ PHP_MINIT_FUNCTION */
PHP_MINIT_FUNCTION(parse_tree)
{
	/* add your stuff here */
	return SUCCESS;
}
/* }}} */

/* {{{ PHP_MSHUTDOWN_FUNCTION */
PHP_MSHUTDOWN_FUNCTION(parse_tree)
{
	/* add your stuff here */
	return SUCCESS;
}
/* }}} */

/* {{{ PHP_MINFO_FUNCTION */
PHP_MINFO_FUNCTION(parse_tree)
{
	php_info_print_table_start();
	php_info_print_table_header(2, "Parse Tree Support", "enabled");
	php_info_print_table_end();
}
/* }}} */

/* {{{ proto void parse_tree_from_file(string filename)
  Generates a parse tree for a PHP source file in XML format. */
PHP_FUNCTION(parse_tree_from_file)
{
	extern char* file_name;
	int filename_len = 0;
	extern FILE* yyin;
	extern char* _xml_output;
	extern int _error;

	if(zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "s", &file_name, &filename_len) == FAILURE){
		return;
	}

	if (filename_len < 1) {
		RETURN_FALSE;
	}


	yyin = fopen(file_name, "r");
	if (!yyin) {
		RETURN_FALSE;
	}

	if (!yyin) {
		RETURN_FALSE;
	}
	yyparse();
	fclose(yyin);
	if(_error){
		return;
	}
	ZVAL_STRING(return_value, _xml_output,1);
	return;
}
/* }}} parse_tree_from_file */

#endif /* HAVE_PARSE_TREE */

/*
 * Local variables:
 * tab-width: 4
 * c-basic-offset: 4
 * End:
 * vim600: noet sw=4 ts=4 fdm=marker
 * vim<600: noet sw=4 ts=4
 */
